Welcome to python-vibrato's documentation!
==========================================

`Vibrato`_ is a fast implementation of tokenization (or morphological analysis) based on the
Viterbi algorithm. This is a Python wrapper for Vibrato.

.. _Vibrato: https://github.com/daac-tools/vibrato

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
